import { HTTPClient, Context } from "koajax";
import { DataObject, ListModel, NewData, IDType, RESTClient } from "mobx-restful";
import { IndexKey, TypeKeys, AbstractClass } from "web-utility";
export const congressClient: HTTPClient<Context>;
export interface Base {
    updateDate: string;
    url?: string;
}
export type ItemLink = Record<'citation' | 'url', string>;
export interface ListLink {
    url: string;
    count: number;
}
export type Chamber = 'House' | 'Senate';
export interface CongressID {
    congress?: number;
    chamber?: Chamber;
}
export const createListStream: <D extends DataObject>() => <K extends string>(key: K) => (this: ListModel<D>) => AsyncGenerator<D, void, unknown>;
export type Depiction = Record<'attribution' | 'imageUrl', string>;
export interface Leadership {
    type: string;
    congress: number;
}
export interface PartyHistory extends Record<`party${'Name' | 'Abbreviation'}`, string> {
    startYear: number;
}
export interface Term extends Record<'congress' | 'startYear' | 'endYear', number>, Record<`state${'Code' | 'Name'}`, string> {
    chamber: Chamber;
    memberType: 'Senator';
}
export interface MemberBase extends Base, Record<'bioguideId' | 'name' | 'partyName' | 'state', string> {
    district?: string;
    depiction: Depiction;
    terms: {
        item: Term[];
    };
}
export interface MemberProfile extends Record<`${'first' | 'last' | 'honorific' | `${'direct' | 'inverted'}Order`}Name`, string> {
    birthYear: string;
}
export interface MemberResume extends Record<`${'' | 'co'}sponsoredLegislation`, {
    count: number;
    url: string;
}> {
    leadership: Leadership[];
    partyHistory: PartyHistory[];
}
export type Member = MemberBase & Partial<MemberProfile & MemberResume>;
export interface MemberOption {
    congress?: number;
    stateCode?: string;
    district?: string;
}
declare const MemberModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Member, void, any>;
    openStream(filter: Partial<NewData<Member>>): AsyncGenerator<Member, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Member, Partial<NewData<Member>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Member>>, newCount: number): Promise<Member[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Member>>): Promise<{
        pageData: Member[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Member>>;
    totalCount: number | undefined;
    pageList: Member[][];
    readonly currentPage: Member[];
    readonly pageCount: number;
    readonly allItems: Member[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Member, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Member, Partial<NewData<Member>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Member>>): Promise<{
        pageData: Member[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Member>>, pageIndex?: number, pageSize?: number): Promise<Member[]>;
    refreshList(): Promise<Member[]>;
    getAll(filter?: Partial<NewData<Member>>, pageSize?: number): Promise<Member[]>;
    countAll(keys: TypeKeys<Member, IndexKey>[], filter?: Partial<NewData<Member>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Member, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Member>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Member>>, id?: IDType): Promise<Member>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof MemberProfile | keyof MemberResume | keyof MemberBase;
    currentOne: Member;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Member>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Member, Partial<NewData<Member>>>>;
export class MemberModel extends MemberModel_base {
    baseURI: string;
    client: HTTPClient<Context>;
    accessor currentLegislation: Record<LegislationModel['type'], LegislationModel> | undefined;
    constructor({ congress, stateCode, district }?: MemberOption);
    openStream: (this: ListModel<Member, Partial<NewData<Member>>>) => AsyncGenerator<Member, void, unknown>;
    getOne(bioguideId: string): Promise<Member>;
}
export interface Legislation extends Record<'number' | 'title' | 'congress' | 'introducedDate' | 'url', string> {
    type: 'S';
    latestAction: Record<'actionDate' | 'text', string>;
    policyArea: {
        name: string;
    };
}
declare const LegislationModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Legislation, void, any>;
    openStream(filter: Partial<NewData<Legislation>>): AsyncGenerator<Legislation, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Legislation, Partial<NewData<Legislation>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Legislation>>, newCount: number): Promise<Legislation[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Legislation>>): Promise<{
        pageData: Legislation[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Legislation>>;
    totalCount: number | undefined;
    pageList: Legislation[][];
    readonly currentPage: Legislation[];
    readonly pageCount: number;
    readonly allItems: Legislation[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Legislation, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Legislation, Partial<NewData<Legislation>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Legislation>>): Promise<{
        pageData: Legislation[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Legislation>>, pageIndex?: number, pageSize?: number): Promise<Legislation[]>;
    refreshList(): Promise<Legislation[]>;
    getAll(filter?: Partial<NewData<Legislation>>, pageSize?: number): Promise<Legislation[]>;
    countAll(keys: TypeKeys<Legislation, IndexKey>[], filter?: Partial<NewData<Legislation>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Legislation, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Legislation>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Legislation>>, id?: IDType): Promise<Legislation>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof Legislation;
    currentOne: Legislation;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Legislation>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Legislation, Partial<NewData<Legislation>>>>;
export class LegislationModel extends LegislationModel_base {
    bioguideId: string;
    type: 'sponsored' | 'cosponsored';
    client: HTTPClient<Context>;
    constructor(bioguideId: string, type?: 'sponsored' | 'cosponsored');
    openStream: (this: ListModel<Legislation, Partial<NewData<Legislation>>>) => AsyncGenerator<Legislation, void, unknown>;
}
export interface Sponsor extends Pick<Member, 'bioguideId' | 'district' | 'firstName' | 'lastName' | 'state' | 'url'>, Record<`${'full' | 'middle'}Name` | 'party', string> {
    isByRequest: 'N';
}
export type CostEstimate = Record<'title' | 'description' | 'pubDate' | 'url', string>;
export interface BillRelations extends Record<'titles' | 'subjects' | 'committees' | 'textVersions' | 'actions' | 'amendments' | 'relatedBills' | 'summaries', ListLink> {
    sponsors?: Sponsor[];
    cosponsors?: ListLink & {
        countIncludingWithdrawnCosponsors: number;
    };
    committeeReports?: ItemLink[];
    laws?: Record<'type' | 'number', string>[];
    cboCostEstimates?: CostEstimate[];
}
export interface Bill extends Base, Record<'number' | 'title' | `originChamber${'' | 'Code'}` | 'updateDateIncludingText', string>, Partial<BillRelations> {
    type: 'hr' | 's' | `${'h' | 's'}${'' | 'j' | 'con'}res`;
    congress: number;
    policyArea?: {
        name: string;
    };
    constitutionalAuthorityStatementText?: string;
    introducedDate?: string;
    latestAction?: Record<'actionDate' | 'text', string>;
}
export interface BillOption {
    congress?: number;
    billType?: Bill['type'];
}
declare const BillModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Bill, void, any>;
    openStream(filter: Partial<NewData<Bill>>): AsyncGenerator<Bill, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Bill, Partial<NewData<Bill>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Bill>>, newCount: number): Promise<Bill[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Bill>>): Promise<{
        pageData: Bill[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Bill>>;
    totalCount: number | undefined;
    pageList: Bill[][];
    readonly currentPage: Bill[];
    readonly pageCount: number;
    readonly allItems: Bill[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Bill, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Bill, Partial<NewData<Bill>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Bill>>): Promise<{
        pageData: Bill[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Bill>>, pageIndex?: number, pageSize?: number): Promise<Bill[]>;
    refreshList(): Promise<Bill[]>;
    getAll(filter?: Partial<NewData<Bill>>, pageSize?: number): Promise<Bill[]>;
    countAll(keys: TypeKeys<Bill, IndexKey>[], filter?: Partial<NewData<Bill>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Bill, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Bill>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Bill>>, id?: IDType): Promise<Bill>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof Bill;
    currentOne: Bill;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Bill>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Bill, Partial<NewData<Bill>>>>;
export class BillModel extends BillModel_base implements BillOption {
    baseURI: string;
    client: HTTPClient<Context>;
    congress?: number;
    billType?: Bill['type'];
    constructor({ congress, billType }?: BillOption);
    openStream: (this: ListModel<Bill, Partial<NewData<Bill>>>) => AsyncGenerator<Bill, void, unknown>;
    getOne(billNumber: string): Promise<Bill>;
}
export interface Summary extends Base, Record<'versionCode' | `currentChamber${'' | 'Code'}` | `action${'Date' | 'Desc'}` | 'lastSummaryUpdateDate' | 'text', string> {
    bill: Bill;
}
declare const SummaryModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Summary, void, any>;
    openStream(filter: Partial<NewData<Summary>>): AsyncGenerator<Summary, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Summary, Partial<NewData<Summary>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Summary>>, newCount: number): Promise<Summary[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Summary>>): Promise<{
        pageData: Summary[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Summary>>;
    totalCount: number | undefined;
    pageList: Summary[][];
    readonly currentPage: Summary[];
    readonly pageCount: number;
    readonly allItems: Summary[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Summary, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Summary, Partial<NewData<Summary>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Summary>>): Promise<{
        pageData: Summary[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Summary>>, pageIndex?: number, pageSize?: number): Promise<Summary[]>;
    refreshList(): Promise<Summary[]>;
    getAll(filter?: Partial<NewData<Summary>>, pageSize?: number): Promise<Summary[]>;
    countAll(keys: TypeKeys<Summary, IndexKey>[], filter?: Partial<NewData<Summary>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Summary, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Summary>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Summary>>, id?: IDType): Promise<Summary>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof Summary;
    currentOne: Summary;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Summary>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Summary, Partial<NewData<Summary>>>>;
export class SummaryModel extends SummaryModel_base {
    baseURI: string;
    client: HTTPClient<Context>;
    constructor({ congress, billType }?: BillOption);
    openStream: (this: ListModel<Summary, Partial<NewData<Summary>>>) => AsyncGenerator<Summary, void, unknown>;
}
export interface Session extends Record<'startDate' | 'endDate', string> {
    type: 'R';
    number: number;
    chamber: Chamber;
}
export interface Congress extends Base, Required<Pick<Term, 'startYear' | 'endYear'>> {
    name: string;
    sessions: Session[];
}
declare const CongressModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Congress, void, any>;
    openStream(filter: Partial<NewData<Congress>>): AsyncGenerator<Congress, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Congress, Partial<NewData<Congress>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Congress>>, newCount: number): Promise<Congress[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Congress>>): Promise<{
        pageData: Congress[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Congress>>;
    totalCount: number | undefined;
    pageList: Congress[][];
    readonly currentPage: Congress[];
    readonly pageCount: number;
    readonly allItems: Congress[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Congress, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Congress, Partial<NewData<Congress>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Congress>>): Promise<{
        pageData: Congress[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Congress>>, pageIndex?: number, pageSize?: number): Promise<Congress[]>;
    refreshList(): Promise<Congress[]>;
    getAll(filter?: Partial<NewData<Congress>>, pageSize?: number): Promise<Congress[]>;
    countAll(keys: TypeKeys<Congress, IndexKey>[], filter?: Partial<NewData<Congress>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Congress, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Congress>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Congress>>, id?: IDType): Promise<Congress>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof Congress;
    currentOne: Congress;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Congress>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Congress, Partial<NewData<Congress>>>>;
export class CongressModel extends CongressModel_base {
    baseURI: string;
    client: HTTPClient<Context>;
    accessor thisYearOne: Congress | undefined;
    accessor currentSummary: SummaryModel | undefined;
    openStream: (this: ListModel<Congress, Partial<NewData<Congress>>>) => AsyncGenerator<Congress, void, unknown>;
    getOne(congress: number): Promise<Congress>;
    getThisYearOne(): Promise<Congress>;
}
export type BaseCommittee = Record<'systemCode' | 'name' | 'url', string>;
export interface CommitteeHistory extends Record<`${'libraryOfCongress' | 'official'}Name` | `${'start' | 'update'}Date`, string> {
    endDate?: string;
}
export interface Committee extends BaseCommittee {
    chamber: Chamber;
    committeeTypeCode: 'Standing';
    updateDate: string;
    history: CommitteeHistory[];
    isCurrent?: boolean;
    communications?: ListLink;
    reports?: ListLink;
    bills?: ListLink;
    parent?: BaseCommittee;
    subcommittees: BaseCommittee[];
}
declare const CommitteeModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Committee, void, any>;
    openStream(filter: Partial<NewData<Committee>>): AsyncGenerator<Committee, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Committee, Partial<NewData<Committee>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Committee>>, newCount: number): Promise<Committee[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Committee>>): Promise<{
        pageData: Committee[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Committee>>;
    totalCount: number | undefined;
    pageList: Committee[][];
    readonly currentPage: Committee[];
    readonly pageCount: number;
    readonly allItems: Committee[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Committee, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Committee, Partial<NewData<Committee>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Committee>>): Promise<{
        pageData: Committee[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Committee>>, pageIndex?: number, pageSize?: number): Promise<Committee[]>;
    refreshList(): Promise<Committee[]>;
    getAll(filter?: Partial<NewData<Committee>>, pageSize?: number): Promise<Committee[]>;
    countAll(keys: TypeKeys<Committee, IndexKey>[], filter?: Partial<NewData<Committee>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Committee, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Committee>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Committee>>, id?: IDType): Promise<Committee>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof Committee;
    currentOne: Committee;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Committee>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Committee, Partial<NewData<Committee>>>>;
export class CommitteeModel extends CommitteeModel_base implements CongressID {
    baseURI: string;
    client: HTTPClient<Context>;
    congress?: number;
    chamber?: Chamber;
    constructor({ congress, chamber }?: CongressID);
    openStream: (this: ListModel<Committee, Partial<NewData<Committee>>>) => AsyncGenerator<Committee, void, unknown>;
    getOne(committeeCode: string): Promise<Committee>;
}
export interface Hearing extends Base, Record<'congress' | 'jacketNumber', number> {
    chamber: Chamber;
    libraryOfCongressIdentifier?: string;
    citation?: string;
    associatedMeeting?: Record<'eventId' | 'url', string>;
    committees?: Committee[];
    formats?: Record<'type' | 'url', string>[];
    dates?: {
        date: string;
    }[];
}
declare const HearingModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Hearing, void, any>;
    openStream(filter: Partial<NewData<Hearing>>): AsyncGenerator<Hearing, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Hearing, Partial<NewData<Hearing>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<NewData<Hearing>>, newCount: number): Promise<Hearing[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Hearing>>): Promise<{
        pageData: Hearing[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<NewData<Hearing>>;
    totalCount: number | undefined;
    pageList: Hearing[][];
    readonly currentPage: Hearing[];
    readonly pageCount: number;
    readonly allItems: Hearing[];
    readonly noMore: boolean;
    statistic: Partial<Record<TypeKeys<Hearing, IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Hearing, Partial<NewData<Hearing>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<NewData<Hearing>>): Promise<{
        pageData: Hearing[];
        totalCount: number;
    }>;
    getList(filter?: Partial<NewData<Hearing>>, pageIndex?: number, pageSize?: number): Promise<Hearing[]>;
    refreshList(): Promise<Hearing[]>;
    getAll(filter?: Partial<NewData<Hearing>>, pageSize?: number): Promise<Hearing[]>;
    countAll(keys: TypeKeys<Hearing, IndexKey>[], filter?: Partial<NewData<Hearing>>, pageSize?: number): Promise<Partial<Record<TypeKeys<Hearing, IndexKey>, Record<string, number>>>>;
    indexOf(id: IDType): number;
    changeOne(data: Partial<Hearing>, id: IDType, patch?: boolean): void;
    updateOne(data: Partial<NewData<Hearing>>, id?: IDType): Promise<Hearing>;
    removeOne(id: IDType): Promise<void>;
    deleteOne(id: IDType): Promise<void>;
    client: RESTClient;
    baseURI: string;
    indexKey: keyof Hearing;
    currentOne: Hearing;
    clearCurrent(): void;
    getOne(id: IDType): Promise<Hearing>;
    downloading: number;
    uploading: number;
}) & AbstractClass<ListModel<Hearing, Partial<NewData<Hearing>>>>;
export class HearingModel extends HearingModel_base implements CongressID {
    baseURI: string;
    client: HTTPClient<Context>;
    congress?: number;
    chamber?: Chamber;
    constructor({ congress, chamber }?: CongressID);
    openStream: (this: ListModel<Hearing, Partial<NewData<Hearing>>>) => AsyncGenerator<Hearing, void, unknown>;
    getOne(jacketNumber: number): Promise<Hearing>;
}

//# sourceMappingURL=index.d.ts.map
